@@ -11,8 +11,7 @@
 #' @param object An object of class \code{KFS}.
 #' @param \dots Ignored.
 #' @return The value of the deviance extracted from object.
-deviance.KFS <- 
-  function(object, ...) {
-    .Deprecated()
-    sum(residuals(object, type = "deviance")^2, na.rm = TRUE)
+deviance.KFS <- function(object, ...) {
+  .Deprecated()
+  sum(residuals(object, type = "deviance")^2, na.rm = TRUE)
 } 
